# R-Code for documentation to the article
# Unfortunately the data cannot be made available for download
# We hope the code iteself also helps explain what we did in the electricity
# demand estimation of our paper:

# Zeyringer, M; Pachauri, S; schmid, E; Schmidt, J; Worrell, E; Morawetz, UB (2015): 
# Analyzing grid extension and stand-alone photovoltaic systems for the cost-effective 
# electrification of Kenya.  ENERGY SUSTAIN DEV. 2015; 25: 75-86. 
# The data cannot be made available. 

# The code is written in R which can be downloaded from www.r-project.org


# This is the part1 file. Start with this file


   ###################################################################################
   # Preparations
            # load the following packages
            # if the packages are not installed you need to install them first: e.g. install.packages("mhurdle")
              library(mhurdle)
              library(weights)
              library(lmtest)         
              

            # set the working directory 
             # e.g. linux
               # setwd("/home/user/data/")  
             # e.g. windows
                setwd("E:/mydirctory/data/")
              
  
              
              
              
            # Read the data as CSV (german version (separator is ";", for english csv write "read.csv()"" instead))
               electken<- read.csv2("variables_1506.csv") # unfortunately the data cannot be provided for download
                    
                 
              # Description of variables  
              # id_clust: Number of the cluster of household survey. Total no of clusters is 1343. For details see: "http://www.knbs.or.ke/pdf/Basic%20Report%20(Revised%20Edition).pdf"
              # id_hh: ID of household. In each cluster there are 10 households. For details see: "http://www.knbs.or.ke/pdf/Basic%20Report%20(Revised%20Edition).pdf"
              # val: value of the house in ????
              # edu: Education in years
              # h: is the household within 100 m. Has been improved with the variable h1. Use h1 instead  
              # D*: Dummy variables for districts. Compare with the variable "districts"
              # head_age: age of the household head in years
              # no: number of people in the household
              # children_school: number of children in the household going to school 
              # children_school: number of children in the household
              # HH_children: Households with children=1, households without children=0              
              # head_woman: Gender of head of household 1=woman, 0=man
              # School_Percentage: Percentage of children (under 18) living in the household and going to school
              # hours_work1: number of hours the household worked for pay during the last 7 days
              # hours_work2: number of hours the household worked on the farm during the last 7 days
              # hours_work3: number of hours the household worked in a household enterprise during the last 7 days
              # hours_work123:  sum of hours_work1, hours_work2, hours_work3
              # no_work1: number of people of the household having worked for pay during the last 7 days
              # no_work2: number of people of the household having worked on the farm during the last 7 days
              # no_work3: number of people of the household having worked for pay during the last 7 days
              # no_work_123: sum of "no_work1", "no_work2", "no_work3"
              # weight: weight which indicates how many households are represented by the household from the survey
              # rural: if household lives in a place which population was estimated to be less then 2000 in the 1999 Pupulation and Houseing Census. See page xv of "http://www.knbs.or.ke/pdf/Basic%20Report%20(Revised%20Edition).pdf"              
              # ed: electricity demand in watts in the last month (ccording to page 28 of questionnaire (Question H38.8) ????)
              # cost_electricity: expenses for electricity in the last month in KSHS. We found this variable not to be very reliable.
              # cost_kerosine: expenses for kerosine in the last month in KSHS
              # cost_gas: expenses for gas in the last month in KSHS
              # cost_firewood: expenses for firewood in the last month in KSHS              
              # h1: "Does HH usually have any electricity working in the dwelling? == YES &  "Although you do not have electricity here, are there HH connected within 100m from the dwelling?"== YES
              # district: District of the household in a variable giving at the first digit the region and in the second and third the district of the region. Total of 70.
              # "non_food_exp_month" : expenditures in Kenyan Shilling on non food items during the last month
              # "exp_food_week": expenditures in KSh on food items during the last month
              # "floor_house1": floor area of all rooms in m2 of the main building
              # "floor_house2": floor area of all rooms in m2 in other building
              # "servants_no": number of domestic servants employed in the household
              # "business_yes_no": does anyone in the household operate a non-agricultural income-generating enterprise (yes=1, no=2)
              # "hh_members_business": number of household members in the last one month who are engaged in the business
              # "sales_business": total sales for the business in KShg
              # "electricity_costs_business": business costs for water and electricity over the last month
              # "employees_business": number of employees in the business who are not household members in the last one month
              # "business_inside_home": is the business operated at home?
              # "electricity_cost_business": Business costs for electricity and water in KSh in the last month
              # "water_into_house": main source of water of last month is piped into the dwelling
              # "flusing_toilet": main toilet is a flush toilet
              # "salary": payment for wages  of all household members and salary last month
              # "Electricity_demand_betrieb" : electricity demand in the business
              #  "Nairobi" "Central" "Coast"  "Eastern" "NorthEastern" "Nyanza" "RiftValley" "Western" 
              # "floor_house1_new": clearned version of "floor_house1"
              # "servent_new": cleaned version of "servant_no" 
              # "non_food_exp_person": non food expenditures per person
              # "q20": Amount earned or lost  from this income generating activity over the past six month
              # "q20_business_home_out": Amount earned or lost  from this income generating activity over the past six month in the home inside the residence
              # "q20_business_home_in": Amount earned or lost  from this income generating activity over the past six month in the home outside the residence
              # "business_home_out": business is operated in the home inside the residence
              # "business_home_in": business is operated in the home outside the residence
   
   
            # Do some obvious data clearing which is uncontroversial
            # and save these data as "electken1"  
              
         #Business related variables
            #  "sales_business"  
            #  "electricity_costs_business" 
            #  "employees_business"         
            #  "business_inside_home"
            #  "electricity_costs_business"
              
              
              # Drop observation where electricity demand ("ed") is "NA""     (1 Obsersvation only)
                 electken1<-electken[-which(is.na(electken$ed)),]
               # Drop the one observation where consumption is zero, but there are expenses for electricity  (two households)
                 electken1<-electken1[-c(which(electken1$cost_electricity>0&electken1$ed==0)),]
               # Drop observations where head of HH is <16 (three households)
                 electken1<-electken1[electken1$head_age>16,]             
               # Drop Nairobi and Mombasa
                 electken1<-electken1[electken1$district!="101"&electken1$district!="304",]
               # the variable "business_inside_home" is either NA or 1. change to 0 if NA
                 electken1$business_inside_home[is.na(electken1$business_inside_home)] <- 0
               # the variable "flusing_toilet" is either NA or 1. change to 0 if NA
                 electken1$flusing_toilet[is.na(electken1$flusing_toilet)] <- 0
               # the variable "water_into_house" is either NA or 1. change to 0 if NA
                 electken1$water_into_house[is.na(electken1$water_into_house)] <- 0
              # the variable "cost_electricity" is either NA or positive. change to 0 if NA
                 electken1$cost_electricity[is.na(electken1$cost_electricity)] <- 0
              # the variable "Electricity_demand_betrieb" is either NA or positive. change to 0 if NA
                 electken1$Electricity_demand_betrieb[is.na(electken1$Electricity_demand_betrieb)] <- 0
              # the variable "sales_business" is either NA or positive. change to 0 if NA
                 electken1$sales_business[is.na(electken1$sales_business)] <- 0
              # the variable "hh_members_business" is either NA or positive. change to 0 if NA
                 electken1$hh_members_business[is.na(electken1$hh_members_business)] <- 0
              # the variable "employees_business" is either NA or positve. change to 0 if NA
                 electken1$employees_business[is.na(electken1$employees_business)] <- 0
              # changes to "business_yes_no"
                # there is one observation with business_yes_no==1.33333333333333. Change to 1 as the business has no employees and the business is not inside the home.
                electken1$business_yes_no[electken1$business_yes_no==1.33333333333333&is.na(electken1$business_yes_no)==FALSE] <- 1
                # there are twenty observation with business_yes_no==1.5. Change to 1 if either there are employees in the business or the business is inside the home. Change to two otherwise.
                electken1$business_yes_no[electken1$business_yes_no==1.5&is.na(electken1$business_yes_no)==FALSE&(electken1$employees_business>0|electken1$business_inside_home==1)] <- 1
                electken1$business_yes_no[electken1$business_yes_no==1.5&is.na(electken1$business_yes_no)==FALSE&(electken1$employees_business==0&electken1$business_inside_home==0)] <- 2
              # the variable "business_yes_no" is either NA or 1 or 2. change to yes if 1 and no if 2.
                 electken1$business_yes_no <-  as.character(electken1$business_yes_no)
                 electken1$business_yes_no[electken1$business_yes_no=="1"] <- "yes"
                 electken1$business_yes_no[electken1$business_yes_no=="2"] <- "no"
                 electken1$business_yes_no <-  as.factor(electken1$business_yes_no)
                 electken1$business_yes_no <-  relevel(electken1$business_yes_no, ref="yes")
              # Set HH with 35 serveant to NA
               electken1$servants_no[electken1$servants_no==35&is.na(electken1$servants_no)==FALSE]<-NA
   
      ## Variables whith unclear meaning:       
            #  electricity_costs_business
            #  electricity_cost_business
      # "sales_business": total sales for the business in KShg            
      #> summary(electken2$sales_business)
      #Min. 1st Qu.  Median    Mean 3rd Qu.    Max.    NA's 
      #1.00    1.00    1.00    1.28    1.00   10.00    2787
              
              ihs <- function(x) {log(x+((x^2)+1)^0.5)}  
  
              
            # Generate variables which are needed later
               # Rename the variable (for consistency in names) which counts the total number of persons which worked in the last 7 days
                 electken1$no_work123<- electken1$no_work_123 # electken1$no_work1+electken1$no_work2+electken1$no_work3
               # Change the district variable to a factor
                 electken1$district<-as.factor(electken1$district)
               # Make interaction and squared terms    
                 electken1$no2<-electken1$no^2              
                 electken1$head_age2<-electken1$head_age^2              
                 electken1$edu2<-electken1$edu^2              
                 electken1$edu3<-electken1$edu^3              
                 electken1$no_work1232<-electken1$no_work123^2              
                 electken1$no_work123rural<-electken1$no_work123*electken1$rural
                 electken1$eduhead_age<-electken1$edu*electken1$head_age              
                 electken1$no_work123rural2<-(electken1$no_work123rural)^2
                 electken1$no_rural<-electken1$no*electken1$rural
                 electken1$no2_rural<-(electken1$no)^2*electken1$rural
                 electken1$ihs_non_food_exp_month<-ihs(electken1$non_food_exp_month)
                 electken1$ihs_exp_food_week<-ihs(electken1$exp_food_week)
                 electken1$ihs_employees_business<- ihs(electken1$employees_business)
                 electken1$business_inside_homeihs_employees_business<- electken1$business_inside_home*electken1$ihs_employees_business
                 electken1$ihs_non_food_exp_person <- ihs(electken1$non_food_exp_person)
                 # the variable "business_home_out" is either NA or 1. change to 0 if NA
                 electken1$business_home_out[is.na(electken1$business_home_out)] <- 0
                 # the variable "business_home_in" is either NA or 1. change to 0 if NA
                 electken1$business_home_in[is.na(electken1$business_home_in)] <- 0
                 # Generate variable which is 1 if "business_home_in" OR "business_home_out" is 1
                 electken1$business_home_in_or_out <- 0
                 electken1$business_home_in_or_out[electken1$business_home_out==1|electken1$business_home_in==1]<-1
              # Delet nonsens variables "VAR00001"and "VAR00002"
                 electken1  <-  electken1[,(names(electken1) %in% c("VAR00001", "VAR00002"))==FALSE]
              # the floor_house1 is very differen: between 0 and 5000m2
                 electken1$ihs_floor_house1<-ihs(electken1$floor_house1)
              # the floor_house1_new causes problems of convergence in tobit. we take the log instead
                 electken1$log_floor_house1_new     <-log(electken1$floor_house1_new)
              
          # Prepare a data set for the estimation of the electricity demand of those who can connect to the grid
          # Save this new data set as "electken2"    
              # Keep only households where h1=1 ("Does HH usually have any electricity working in the dwelling?" & 
              #                                   "Although you do not have electricity here, are there HH connected within 100m from the dwelling?")
                  electken2<-electken1[electken1$h1==1,]
              
              # In case it is necessary to drop some high electricity users uncomment the following code
                # Drop households which use more than XXD electricity
                  # max_elect_demand<-max(electken1$ed)
                  # max_elect_demand<-quantile(electken1$ed, probs=c(.95), na.rm=TRUE)
                  # max_elect_demand<-40000
                  # electken2<-electken2[electken1$ed<max_elect_demand,]


   ###################################################################################
   # Comparison of means of household characterisits between househlds which are close (<100m) to electricity grid and those which are not.

         # Comparisions of mean for districts where more than "minHH"" from sample are <100 m to electricity connection.
          # Preparations  
              # Set minimum number of households
               minHH<-30
              # Make matrix to be filled with values  
               meanCharaceristics<-matrix(NA,nrow=length(levels(electken1$district)[table(electken1$district[electken1$h1==1])>minHH]), ncol=5)

          # 1)  Number of household Members
              laufindex<-0
              meanNumberHHmembers<-meanCharaceristics
                  for(i in levels(electken1$district)[table(electken1$district[electken1$h1==1])>minHH]) {
                      laufindex<-laufindex+1
                      meanNumberHHmembers[laufindex,1]<-i
                      meanNumberHHmembers[laufindex,2]<-wtd.t.test(electken1$no[electken1$h1==0 &electken1$district==i],electken1$no[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$additional[2]
                      meanNumberHHmembers[laufindex,3]<-wtd.t.test(electken1$no[electken1$h1==0 &electken1$district==i],electken1$no[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$additional[3]
                      meanNumberHHmembers[laufindex,4]<-wtd.t.test(electken1$no[electken1$h1==0 &electken1$district==i],electken1$no[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$coefficients[3]
                      }
                  meanNumberHHmembers[as.numeric(meanNumberHHmembers[,4])<.05,5]<-"*"
                  colnames(meanNumberHHmembers)<-c("district","mean no grid", "mean grid", "p-value","sign 0.05")
                  write.csv(meanNumberHHmembers, "MeanNumber_HHmembers.csv")


          # 2) Age of household head
              laufindex<-0
              meanAge_HH_head<-meanCharaceristics
                  for(i in levels(electken1$district)[table(electken1$district[electken1$h1==1])>minHH]) {
                    laufindex<-laufindex+1
                    meanAge_HH_head[laufindex,1]<-i
                    meanAge_HH_head[laufindex,2]<-wtd.t.test(electken1$head_age[electken1$h1==0 &electken1$district==i],electken1$head_age[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$additional[2]
                    meanAge_HH_head[laufindex,3]<-wtd.t.test(electken1$head_age[electken1$h1==0 &electken1$district==i],electken1$head_age[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$additional[3]
                    meanAge_HH_head[laufindex,4]<-wtd.t.test(electken1$head_age[electken1$h1==0 &electken1$district==i],electken1$head_age[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$coefficients[3]
                    }
                  meanAge_HH_head[as.numeric(meanAge_HH_head[,4])<.05,5]<-"*"
                  colnames(meanAge_HH_head)<-c("district","mean no grid", "mean grid", "p-value","sign 0.05")
                  write.csv(meanAge_HH_head, "MeanAgeHH_head.csv")

          # 3) Education household head
             laufindex<-0
             meanEducation_HH_head<-meanCharaceristics
                  for(i in levels(electken1$district)[table(electken1$district[electken1$h1==1])>minHH]) {
                    laufindex<-laufindex+1
                    meanEducation_HH_head[laufindex,1]<-i
                    meanEducation_HH_head[laufindex,2]<-wtd.t.test(electken1$edu[electken1$h1==0 &electken1$district==i],electken1$edu[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$additional[2]
                    meanEducation_HH_head[laufindex,3]<-wtd.t.test(electken1$edu[electken1$h1==0 &electken1$district==i],electken1$edu[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$additional[3]
                    meanEducation_HH_head[laufindex,4]<-wtd.t.test(electken1$edu[electken1$h1==0 &electken1$district==i],electken1$edu[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$coefficients[3]
                    }
                  meanEducation_HH_head[as.numeric(meanEducation_HH_head[,4])<.05,5]<-"*"
                  colnames(meanEducation_HH_head)<-c("district","mean no grid", "mean grid", "p-value","sign 0.05")
                  write.csv(meanEducation_HH_head, "MeanEducationHHhead.csv")

          # 4) Number of persons who worked in the last 7 days
             laufindex<-0
             meanNumber_worked<-meanCharaceristics
                  for(i in levels(electken1$district)[table(electken1$district[electken1$h1==1])>minHH]) {
                  laufindex<-laufindex+1
                  meanNumber_worked[laufindex,1]<-i
                  meanNumber_worked[laufindex,2]<-wtd.t.test(electken1$no_work123[electken1$h1==0 &electken1$district==i],electken1$no_work123[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$additional[2]
                  meanNumber_worked[laufindex,3]<-wtd.t.test(electken1$no_work123[electken1$h1==0 &electken1$district==i],electken1$no_work123[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$additional[3]
                  meanNumber_worked[laufindex,4]<-wtd.t.test(electken1$no_work123[electken1$h1==0 &electken1$district==i],electken1$no_work123[electken1$h1==1&electken1$district==i], weight=electken1$weight[electken1$h1==0 &electken1$district==i], weighty=electken1$weight[electken1$h1==1&electken1$district==i], samedata=FALSE)$coefficients[3]
                  }
               meanNumber_worked[as.numeric(meanNumber_worked[,4])<.05,5]<-"*"
               colnames(meanNumber_worked)<-c("district","mean no grid", "mean grid", "p-value","sign 0.05")
               write.csv(meanNumber_worked, "MeanNumber_worked.csv")

   #######################
   # Table 3   
  # Non food expenditures per household in KSh per month  
   tab3.non_food_exp_person<- wtd.t.test(electken1$non_food_exp_person[electken1$h1==0],electken1$non_food_exp_person[electken1$h1==1], weight=electken1$weight[electken1$h1==0], weighty=electken1$weight[electken1$h1==1], samedata=FALSE)
  # Number of servants employed in the household 
   tab3.servants_new<- wtd.t.test(electken1$servants_new[electken1$h1==0],electken1$servants_new[electken1$h1==1], weight=electken1$weight[electken1$h1==0], weighty=electken1$weight[electken1$h1==1], samedata=FALSE)
  # Flush toilet as main  toilet facility in % 
   tab3.flusing_toilet<- wtd.t.test(electken1$flusing_toilet[electken1$h1==0],electken1$flusing_toilet[electken1$h1==1], weight=electken1$weight[electken1$h1==0], weighty=electken1$weight[electken1$h1==1], samedata=FALSE)
  # Age of household head in years
   tab3.head_age<- wtd.t.test(electken1$head_age[electken1$h1==0],electken1$head_age[electken1$h1==1], weight=electken1$weight[electken1$h1==0], weighty=electken1$weight[electken1$h1==1], samedata=FALSE)
  # Formal education of household head in years 
   tab3.edu<- wtd.t.test(electken1$edu[electken1$h1==0],electken1$edu[electken1$h1==1], weight=electken1$weight[electken1$h1==0], weighty=electken1$weight[electken1$h1==1], samedata=FALSE)
  # Number of people living in the  household
   tab3.no<- wtd.t.test(electken1$no[electken1$h1==0],electken1$no[electken1$h1==1], weight=electken1$weight[electken1$h1==0], weighty=electken1$weight[electken1$h1==1], samedata=FALSE)
  # Shear of housholds in rural area 
   tab3.rural<- wtd.t.test(electken1$rural[electken1$h1==0],electken1$rural[electken1$h1==1], weight=electken1$weight[electken1$h1==0], weighty=electken1$weight[electken1$h1==1], samedata=FALSE)

   table3<-matrix(c(
   c(tab3.non_food_exp_person$additional[3],tab3.non_food_exp_person$additional[2],if(tab3.non_food_exp_person$coefficients[3]<0.05){"*"}else{""}),
   c(tab3.servants_new$additional[3],      tab3.servants_new$additional[2],      if(tab3.servants_new$coefficients[3]<0.05){"*"}else{""}),
   c(tab3.flusing_toilet$additional[3]    ,tab3.flusing_toilet$additional[2],    if(tab3.flusing_toilet$coefficients[3]<0.05){"*"}else{""}),
   c(tab3.head_age$additional[3]          ,tab3.head_age$additional[2],          if(tab3.head_age$coefficients[3]<0.05){"*"}else{""}),
   c(tab3.edu$additional[3]               ,tab3.edu$additional[2],               if(tab3.edu$coefficients[3]<0.05){"*"}else{""}),
   c(tab3.no$additional[3]                ,tab3.no$additional[2],                if(tab3.no$coefficients[3]<0.05){"*"}else{""}),
   c(tab3.rural$additional[3]             ,tab3.rural$additional[2],             if(tab3.rural$coefficients[3]<0.05){"*"}else{""})),
   byrow=TRUE, ncol=3)
   
   colnames(table3)<-c("Weighted mean of HH within 100 m of electricity supply",
                       "Weighted mean of HH beyond 100 m of electricity supply",
                       "5% significance level"
                       )
   
   rownames(table3)<-c("Non food expenditures per person in KSh per month",
                       "Number of servants employed in the household",
                       "Flush toilet as main  toilet facility in %",
                       "Age of household head in years",
                       "Formal education of household head in years",
                       "Number of people living in the  household",
                       "Housholds in rural area in %"
                       )
   
   write.csv(table3, "table3.csv")
   
   
   ###################################################################################
   # Esitmation of models of electricity demand

            # Predictions of different models will be saved in 
              Prediction_List <- list() # (Do not re-run this line if you want to keep results from previous models in this list)
              # 1) Exponential Model 

              
                          variables<-   c(" ", "rural", "no", "no2", "head_age", "head_age2", "edu", "edu2" , "edu3"  , "head_woman"  , "no_work123"  , "no_work1232" ,  "no_work123rural", "eduhead_age",  "no_rural", "no2_rural",  "ihs_non_food_exp_month", "servants_no",  "business_inside_home", "flusing_toilet", "water_into_house", "Central", "Coast",  "Eastern", "NorthEastern", "Nyanza", "RiftValley", "Western" ,  "business_yes_no", "hh_members_business", "sales_business", "ihs_employees_business", "business_inside_homeihs_employees_business" , "children_school", "children", "School_percentage", "HH_children", "ihs_exp_food_week","ihs_non_food_exp_person", "business_home_out", "business_home_in", "business_home_in_or_out", "ihs_floor_house1", "ihs_costs_firewood", "servants_new","floor_house1_new", "log_floor_house1_new" )
                          startvalues<- c(100,   .01 ,  0.4,-0.004, 0.02       , -.001      , 0.01, -0.005  , .002    ,   -1          ,  0.1          , -0.002        ,  -0.005           ,  0.001       ,   -0.05    ,  0.07      ,  1                       ,       .1      , 2                      ,     .4          ,    .5             ,  0.2     ,   0.2  ,   0.2     ,   0.2         ,   0.2   ,    0.2      ,    0.2    ,    0.1            ,   0.2               ,    1.3         ,    1.5             ,     0.4                                    ,     -0.2         ,   -0.4   ,     0.3           ,  -0.5              ,     0.2                 , .25                     ,  2                 ,  3                ,        4                , .5               , .5                   ,  2            ,       .2         , 0.02)                 
                          index    <-   c(  1,       2,    3,   4  ,    5      ,     6      , 7   ,  8      ,    9    ,  10           ,    11         ,  12           ,  13               ,  14          ,    15      ,  16        ,  17                      ,       18     , 19                     ,   20            ,     21            ,   22     ,    23   ,   24     ,   25          ,   26    ,    27       ,     28    ,     29            ,  30                ,     31          ,   32              ,     33                                      ,      34          ,       35  ,     36            ,     37            ,       38                ,  39                     , 40                 ,  41               ,      42                  , 43               , 44                   ,  45           ,       46         ,  47)                          
                 # The variables you want to include in the model should have a value in the vector "choice"
                 # you can define various models
                 # determine which model is estimated by setting "ModelNr" in the part2 file
                
              cbind(variables, index)
 
 ####
 # Continue with the part2 file
 # "Electricity_Demand_Estimation_Kenya_v13_part2_model_comparison.R"  
   
   
